@@ -18,8 +18,8 @@
  *
  */
 
-#ifndef AKONADI_SEARCH_QUERYPARSER_H
-#define AKONADI_SEARCH_QUERYPARSER_H
+#ifndef AKONADI_SEARCH_XAPIAN_QUERYPARSER_H
+#define AKONADI_SEARCH_XAPIAN_QUERYPARSER_H
 
 #include <QString>
 #include <xapian.h>
@@ -57,4 +57,4 @@ private:
 }
 }
 
-#endif // AKONADI_SEARCH_QUERYPARSER_H
+#endif // AKONADI_SEARCH_XAPIAN_QUERYPARSER_H
